# Contributing to Darwinio

Thank you for your interest in contributing to Darwinio! We welcome all contributions, including bug fixes, feature additions, documentation improvements, and more.

To get started, please follow these steps:
## Step 1: Clone the Repository

Clone the repository to your local machine using the following command in your terminal:

```
git clone https://github.com/tusharhero/darwinio.git

```

*Note: Windows users need to install git bash and set it up with your GitHub account. *

## Step 3: Change to Your Specific Branch

You have to work on a specific branch, change to that branch using the following command:

```
git checkout <branch-name>
```

Replace <branch-name> with the name of the branch you are permitted to work on.

*Ask [@tusharhero](https://github.com/tusharhero) to get the branch name *

## Step 4: Add Individual Files

Add the files you want to modify or add to the staging area using the following command:

```
git add <file-name>
```

Replace <file-name> with the name of the file you want to add.

## Step 5: Commit Your Changes

Commit your changes to the local repository using the following command:

```
git commit -am "Your commit message here"
```

Replace "Your commit message here" with a brief summary of the changes you made.

## Step 6: Push Your Changes

Push your changes to your forked repository on GitHub using the following command:

```
git push origin <branch-name>
```

Replace <branch-name> with the name of the branch you are working on.

## Step 7: Synchronizing with Master

```
git fetch
git pull
```

These commands will `pull` all the new stuff from GitHub. Now to get those stuff into your branch. You have to do,

```
git merge origin/master
```

If there are new changes to master you can get

That's it! Thank you for your contribution to Darwinio. We appreciate your time and effort.
